//! Core algorithms and data structures.

pub mod config;
pub mod eventlog;
pub mod formatting;
pub mod metadata;
pub mod rewrite;
